@@ -8,9 +8,8 @@ class StatusService :
     @ServiceMethod(requestClass=[EnumAsQueryDto.EnumAsQueryRequestDto])
     def findAllByStatus(self, dto):
         if dto.status is None:
-            raise Exception('do Enum still remains as enum?')
+            raise Exception(f'do Enum still remains as enum? --> dto.status: {dto.status}')
         modelList = self.repository.actuatorHealthTest.findAllByStatus(dto.status)
-        print(modelList)
         return self.converter.actuatorHealthTest.fromModelListToResponseDtoList(modelList), {
             'added': 'header',
             'booleanFalse': False,
